@@ -23,7 +23,10 @@ amazon_uk = 'amazonukid'
 amazon_jp = 'amazonjpid'
 amazon_fr = 'amazonfrid'
 amazon_de = 'amazondeid'
+americanas ='americanasid'
+buscape = 'buscapeid'
 ebay = 'ebayid'
+jacotei = 'jacoteiid'
 mercadolivre = 'mercadolivreid'
 submarino = 'submarinoid'
 americanas = 'americanasid'
